"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var assign = require("object-assign");
var FormInput = (function (_super) {
    __extends(FormInput, _super);
    function FormInput(props) {
        var _this = _super.call(this, props) || this;
        _this.formState = {};
        _this.renderField = _this.renderField.bind(_this);
        _this.onValueChanged = _this.onValueChanged.bind(_this);
        return _this;
    }
    FormInput.prototype.renderField = function (field, index) {
        var fieldDef = this.props.registry[field.type];
        if (!fieldDef || !fieldDef.input) {
            console.warn('Field definition is not registered: ' + field.type);
            return;
        }
        var value = this.props.value[field.id];
        var fieldInputProps = {
            registry: this.props.registry,
            index: index,
            field: field,
            value: value,
            context: this.props.context,
            attempt: this.props.attempt,
            onValueChange: this.onValueChanged,
        };
        var component = React.createElement(fieldDef.input, fieldInputProps);
        return (React.createElement("div", { className: 'form-input-field', key: index }, component));
    };
    FormInput.prototype.onValueChanged = function (field, value, fieldStatus) {
        var newValue = assign({}, this.props.value);
        newValue[field.id] = value;
        this.fireValuesChange(newValue);
        if (fieldStatus.error) {
            this.formState[field.id] = fieldStatus;
        }
        else {
            delete this.formState[field.id];
        }
        this.onChange(newValue);
    };
    FormInput.prototype.fireValuesChange = function (value) {
        var _this = this;
        this.props.fields.forEach(function (field, index) {
            var fieldDef = _this.props.registry[field.type];
            if (fieldDef && fieldDef.inputInjector && fieldDef.inputInjector.onValuesChanged) {
                var fieldState = fieldDef.inputInjector.onValuesChanged(field, value);
                if (fieldState) {
                    _this.formState[field.id] = fieldState;
                }
                else {
                    delete _this.formState[field.id];
                }
            }
        });
    };
    FormInput.prototype.fireValuesInit = function (value) {
        var _this = this;
        this.props.fields.forEach(function (field, index) {
            var fieldDef = _this.props.registry[field.type];
            if (fieldDef && fieldDef.inputInjector && fieldDef.inputInjector.onValuesInit) {
                var fieldState = fieldDef.inputInjector.onValuesInit(field, value);
                if (fieldState) {
                    _this.formState[field.id] = fieldState;
                }
                else {
                    delete _this.formState[field.id];
                }
            }
        });
    };
    FormInput.prototype.componentWillMount = function () {
        if (this.props.fields && this.props.value) {
            var newValue = assign({}, this.props.value);
            this.fireValuesInit(newValue);
            this.onChange(newValue);
        }
    };
    FormInput.prototype.onChange = function (value) {
        var formState = Object.keys(this.formState).length > 0 ? this.formState : null;
        this.props.onChange(value, formState);
    };
    // render a list of fields based on the field registry.
    FormInput.prototype.render = function () {
        return (React.createElement("div", { className: 'form-input' }, this.props.fields.map(this.renderField)));
    };
    return FormInput;
}(React.PureComponent));
FormInput.defaultProps = {
    value: {}
};
exports.FormInput = FormInput;
