"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var assign = require("object-assign");
var FormBuilder_1 = require("../FormBuilder");
var FieldBuilderWrapper_1 = require("../FieldBuilderWrapper");
var NestedFormBuilder = (function (_super) {
    __extends(NestedFormBuilder, _super);
    function NestedFormBuilder() {
        var _this = _super.call(this) || this;
        _this.onChangeFields = _this.onChangeFields.bind(_this);
        _this.onBeforeAddField = _this.onBeforeAddField.bind(_this);
        _this.onError = _this.onError.bind(_this);
        _this.canDrop = _this.canDrop.bind(_this);
        return _this;
    }
    NestedFormBuilder.prototype.onChangeFields = function (fields, change) {
        var field = assign({}, this.props.field);
        field.fields = fields;
        this.props.onChange(field, this.props.index, change);
    };
    NestedFormBuilder.prototype.onBeforeAddField = function (field) {
        field.parentId = this.props.field.id;
        var hook = this.props.onBeforeAddField;
        if (hook) {
            return hook(field);
        }
        return true;
    };
    // NOTE(andrews) canDrop holds the business logic for determining if the source item can
    // be dropped on the target item.
    NestedFormBuilder.prototype.canDrop = function (source, target) {
        // NOTE(andrews): Prohibit more than one layer of nested fields
        if (source.field.type === this.props.field.type && target.parentId) {
            return false;
        }
        if (this.props.canDrop) {
            return this.props.canDrop(source, target);
        }
        return true;
    };
    NestedFormBuilder.prototype.onError = function (error) {
        this.props.onError(this.props.field, this.props.index, error);
    };
    NestedFormBuilder.prototype.render = function () {
        return (React.createElement("div", { className: 'form-builder-nested' },
            React.createElement("div", { className: 'form-builder-nested-label' }, this.props.field.label),
            React.createElement(FormBuilder_1.FormBuilder, { editButton: this.props.editButton, deleteButton: this.props.deleteButton, registry: this.props.registry, editingFieldId: this.props.editingFieldId, onFieldEditing: this.props.onFieldEditing, onBeforeAddField: this.onBeforeAddField, fields: this.props.field.fields, onChange: this.onChangeFields, onError: this.onError, canDrag: this.props.canDrag, canDrop: this.canDrop, idGenerator: this.props.idGenerator, parentId: this.props.field.id, emptyLayout: this.props.emptyLayout })));
    };
    return NestedFormBuilder;
}(React.PureComponent));
exports.NestedFormBuilder = NestedFormBuilder;
exports.NestedFormBuilderWrapper = FieldBuilderWrapper_1.createFieldBuilderWrapper()(NestedFormBuilder);
